# Using Webcharts in Angular

For certain scenarios, Webcharts can be incorporated into an Angular application with very little effort.

## Setup

To begin using Webcharts within Angular first run `npm install ni-webcharts` from the root directory of your application. Your Angular root directory should have a file called `angular.json` present, particularly if your project was created from the CLI using something like `ng new <project name>`. Under the `projects->architect->build->options` section, you can add the necessary .js files in the 'scripts' section. The following set of files are recommended to be included at a minimum<sup>[1](#footnote)</sup>:

```json
"scripts": [
    "node_modules/jquery/dist/jquery.min.js",
    "node_modules/flot/lib/jquery.event.drag.js",
    "node_modules/flot/lib/jquery.mousewheel.js",
    "node_modules/flot/dist/es5/jquery.flot.js",
    "node_modules/ni-data-types/dist/es5-minified/ni-data-types.min.js",
    "node_modules/flot-plugins/dist/es5/NationalInstruments/jquery.flot.plugins.js",
    "node_modules/@ni-kismet/jqx-element/source/jqxelement-polyfills.js",
    "node_modules/@ni-kismet/jqx-element/source/jqxelement.js",
    "node_modules/ni-webcharts/dist/es6-minified/element.min.js",
    "node_modules/ni-webcharts/dist/es6-minified/webcharts.min.js",
    "node_modules/ni-webcharts/dist/es6-minified/element_registration.min.js"
]
```
<font size="1"><a name="footnote">1</a>: Note that the above files may have changed since this documentation was last updated (created against webcharts v10.0.0). Please consult the demo linked below for current expected files.</font>

You will also need to bring in the CSS needed to render Webcharts as expected. In the same `angular.json` file, you can add `node_modules/ni-webcharts/styles/webchartsLight.css` to the `"styles":` section.

Finally, in the module containing the component that you intend to use webcharts, you will need to add 'CUSTOM_ELEMENTS_SCHEMA' to the 'schemas' section (see [Angular docs](https://angular.io/api/core/CUSTOM_ELEMENTS_SCHEMA) regarding the reasons).

Once all of this is in place, you should be able to successfully use the Webcharts custom elements in the template of a component. [This demo app](https://github.com/ni-kismet/webcharts-angular-app-demo) shows this in action. 
- Note that the demo app was built against Angular v10.0.5, and there is no current plans to update demo app to newer versions of Angular.

## Type Declarations

To make the experience of using Webcharts within an Angular environment more developer-friendly, it is useful to have Typescript type declarations for the custom elements themselves. In the demo app linked above, an abbreviated set of declarations [are provided](https://github.com/ni-kismet/webcharts-angular-app-demo/blob/master/src/app/webchartsTypes.d.ts) to demonstrate how this can be accomplished. Once in place, the Angular development environment should be able to access the expected members in type-ahead both in the Typescript source, and HTML files.

## A Simple Example

As the linked demo app illustrates, one can easily use Webcharts in Angular with something like the following HTML (Angular-specific syntax explanations will follow below):

```html
      <ni-cartesian-graph id="graph1" [value]="graphData" #graph>
        <ni-cartesian-axis show show-ticks show-minor-ticks show-label label="Time" axis-position="bottom" grid-lines></ni-cartesian-axis>
        <ni-cartesian-axis show show-ticks show-minor-ticks show-label label="Amplitude" axis-position="left" auto-scale="exact" grid-lines></ni-cartesian-axis>
        <ni-cartesian-plot show label="Plot 1" [enableHover]="isHoverEnabled">
          <ni-cartesian-plot-renderer line-width="1.5" line-stroke="#82A3D1"></ni-cartesian-plot-renderer>
        </ni-cartesian-plot>
        <ni-cartesian-plot show label="Plot 2" [enableHover]="isHoverEnabled">
          <ni-cartesian-plot-renderer line-width="1.5" line-stroke="#862323"></ni-cartesian-plot-renderer>
        </ni-cartesian-plot>
      </ni-cartesian-graph>
```
Here, the `ni-cartesian-graph` is placed in the template of an Angular component. The `value` property is "bound" to a property called "graphData" that is defined on the component. When the `graphData` property is changed, the value property will automatically be updated along with it! The graph has been given the name "graph" through the `#graph` syntax, which the component can then use to gain programmatic access to that element.

The rest of the HTML should be fairly familiar as it's representative of a typical usage within HTML. The only other notable aspect is where the `enableHover` property is also bound to a component property, but this is fundamentally no different than the binding of the `value` property noted above.

## Non-supported Use Cases

While Webcharts is fairly easy to use in Angular applications, there are certain patterns that should be avoided, as well as some default behaviors that should be worked around.

### Structural Directives

Angular has some nifty ways to update the DOM dynamically with the use of something called [structural directives](https://angular.io/guide/structural-directives). It's not outlandish for someone to attempt to manage some of the Webcharts custom elements (like plots) through the use of something like the `*ngFor` structural directive (likely paired with something like `ngTemplate` and `ngTemplateOutlet`). However, this can run afoul with Webcharts' own attempts to managed/create DOM elements for plots based on its current data. This makes it difficult/impossible to "templatize" plot elements set up with desired bindings in Angular. Thus, if bindings are required, a static setup for plots is likely your only option (without a, likely, substantive wrapping effort).

### Localization

Webcharts has its own mechanisms for localizing strings for certain things. These mechanisms require certain files to be deployed in particular locations within an app, which is a pretty tough sell for consumers to Webcharts. As such, when doing an 'npm install' of Webcharts in an Angular app, you will not get expected localization behaviors. Thus, the names of auto-generated elements (or, more specifically, elements that have not set their `label` property), will be given a name that is a lookup key for the localized string, instead of the expected string value. To avoid this, the recommendation is that for any DOM element whose label can appear in some way to be provided an explicit value for its `label` property (i.e. axes, plots, cursors).

## Regarding Legends

An initial attempt at bringing in the legends from [webcharts-legends](https://github.com/ni-kismet/webcharts-legends) into the demo app alongside Webcharts resulted in some strange CSS-related behaviors. At this time, it is not recommended to use the legends.

